==> haskell-servant-swagger-1.1.5-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.5
id: servant-swagger-1.1.5-CVfrKSV37A73LPirZ6vp1Y
key: servant-swagger-1.1.5-CVfrKSV37A73LPirZ6vp1Y
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger™ is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: f5df21415aa38af69a5891ee57819884
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-swagger-1.1.5
hs-libraries: HSservant-swagger-1.1.5-CVfrKSV37A73LPirZ6vp1Y
depends:
    aeson-1.3.1.1-GWugBGc2PFu9s1ZSj5WAqo base-4.11.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-2HjNtQ7E0GEFXz8Peblu7w
    lens-4.16.1-8C3gyEvZl3j1uMou7zDcVc
    servant-0.13.0.1-GWgdf0kkYY1N8ooUJx2yF
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    swagger2-2.2.2-8uDW2ibPB6XJ7UAwMVyduW text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    hspec-2.5.2-KD8ovCFRk4VFxViWGpjHpL
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: aeson-1.3.1.1-GWugBGc2PFu9s1ZSj5WAqo=c0ad5c4df215a991062672ba7d02a689
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             insert-ordered-containers-0.2.1.0-2HjNtQ7E0GEFXz8Peblu7w=af2c82d7ac9698ef833a07997f06dd1c
             lens-4.16.1-8C3gyEvZl3j1uMou7zDcVc=86d4507b95bb51758f905ee6d46f989c
             servant-0.13.0.1-GWgdf0kkYY1N8ooUJx2yF=5a89839d63126b725948652ed6511420
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=24df0dfc182470190a9b6f84de345a01
             swagger2-2.2.2-8uDW2ibPB6XJ7UAwMVyduW=c10fb9bcd8b8a97c67221c9a4a956ba1
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             hspec-2.5.2-KD8ovCFRk4VFxViWGpjHpL=62a8daa34d7fa7bd29ac64563ab71ce4
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.5-39-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.5
id: servant-swagger-1.1.5-9gB1kzBpbPr7YJWDSvujJm
key: servant-swagger-1.1.5-9gB1kzBpbPr7YJWDSvujJm
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger™ is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: f3317cda088e07abe8e529b5a1b9aab4
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-swagger-1.1.5
hs-libraries: HSservant-swagger-1.1.5-9gB1kzBpbPr7YJWDSvujJm
depends:
    aeson-1.3.1.1-LHKOu9kAlDG9Y35h5H45Xc base-4.11.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-5ExcZ0WNHMVLCC3JC7FUm8
    lens-4.17-CW9WGGzkOuwK4qFh7wMqCb
    servant-0.13.0.1-2f4tak2RawgCds9Jg59ig7
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    swagger2-2.2.2-D8SG1uFptpOdoe0UxFgFB text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    hspec-2.5.4-84Bn2biJrPdD64wYJt3YHP
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: aeson-1.3.1.1-LHKOu9kAlDG9Y35h5H45Xc=7b52bf10733c633baa1a495dfba64f87
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             insert-ordered-containers-0.2.1.0-5ExcZ0WNHMVLCC3JC7FUm8=6cd537a485c1859b9d9af2f75e4cb7ae
             lens-4.17-CW9WGGzkOuwK4qFh7wMqCb=1af9f3f9335de3bf469a706df0980416
             servant-0.13.0.1-2f4tak2RawgCds9Jg59ig7=4a3f21dac6b98ed7405f6aecf97c6498
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=24df0dfc182470190a9b6f84de345a01
             swagger2-2.2.2-D8SG1uFptpOdoe0UxFgFB=5bc26981c94cb1cf2270b3367abd6e6f
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             hspec-2.5.4-84Bn2biJrPdD64wYJt3YHP=6e51c84767924d270b0cb524a2061329
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
